@@ -376,7 +376,7 @@ ephy_file_helpers_init (const char            *profile_dir,
 
     app_file = g_build_filename (profile_dir, ".app", NULL);
     if (g_file_test (app_file, G_FILE_TEST_EXISTS)) {
-      const char *app_name = ephy_web_application_get_program_name_from_profile_directory (profile_dir_global);
+      const char *app_name = ephy_web_application_get_gapplication_id_from_profile_directory (profile_dir_global);
       cache_dir = g_build_filename (g_get_user_cache_dir (), app_name, NULL);
       config_dir = g_build_filename (g_get_user_config_dir (), app_name, NULL);
       profile_dir_type = EPHY_PROFILE_DIR_WEB_APP;
@@ -713,7 +713,6 @@ ephy_file_open_uri_in_default_browser (const char                   *uri,
  * ephy_file_browse_to:
  * @file: a #GFile
  * @user_time: user_time to prevent focus stealing
- * @tag: used to guard against improper usage
  *
  * Launches the default application for browsing directories to point to
  * @file. E.g. nautilus will jump to @file within its directory and
@@ -722,13 +721,17 @@ ephy_file_open_uri_in_default_browser (const char                   *uri,
  * Returns: %TRUE if the launch succeeded
  **/
 gboolean
-ephy_file_browse_to (GFile                        *file,
-                     guint32                       user_time,
-                     EphyFileHelpersNotFlatpakTag  tag)
+ephy_file_browse_to (GFile   *file,
+                     guint32  user_time)
 {
   g_autofree char *uri = g_file_get_uri (file);
 
-  return open_in_default_handler (uri, "inode/directory", user_time, NULL, tag);
+  if (ephy_is_running_inside_flatpak ()) {
+    ephy_open_directory_via_flatpak_portal (uri);
+    return TRUE;
+  }
+
+  return open_in_default_handler (uri, "inode/directory", user_time, NULL, EPHY_FILE_HELPERS_I_UNDERSTAND_I_MUST_NOT_USE_THIS_FUNCTION_UNDER_FLATPAK);
 }
 
 /**
@@ -851,3 +854,53 @@ ephy_open_incognito_window (const char *uri)
 
   g_free (command);
 }
+
+void
+ephy_copy_directory (const char *source,
+                     const char *target)
+{
+  g_autoptr (GError) error = NULL;
+  GFileType type;
+  g_autoptr (GFile) src_file = g_file_new_for_path (source);
+  g_autoptr (GFile) dest_file = g_file_new_for_path (target);
+
+  type = g_file_query_file_type (src_file, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL);
+
+  if (type == G_FILE_TYPE_DIRECTORY) {
+    g_autoptr (GFileEnumerator) enumerator = NULL;
+    g_autoptr (GFileInfo) info = NULL;
+
+    if (!g_file_make_directory_with_parents (dest_file, NULL, &error)) {
+      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS)) {
+        g_warning ("Could not create target directory for webextension: %s", error->message);
+        return;
+      }
+
+      g_error_free (error);
+    }
+
+    if (!g_file_copy_attributes (src_file, dest_file, G_FILE_COPY_NONE, NULL, &error)) {
+      g_warning ("Could not copy file attributes for webextension: %s", error->message);
+      return;
+    }
+
+    enumerator = g_file_enumerate_children (src_file, G_FILE_ATTRIBUTE_STANDARD_NAME, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL, &error);
+    if (!enumerator) {
+      g_warning ("Could not create file enumberator for webextensions: %s", error->message);
+      return;
+    }
+
+    for (info = g_file_enumerator_next_file (enumerator, NULL, NULL); info != NULL; info = g_file_enumerator_next_file (enumerator, NULL, NULL)) {
+      ephy_copy_directory (
+        g_build_filename (source, g_file_info_get_name (info), NULL),
+        g_build_filename (target, g_file_info_get_name (info), NULL));
+    }
+  } else if (type == G_FILE_TYPE_REGULAR) {
+    if (!g_file_copy (src_file, dest_file, G_FILE_COPY_NONE, NULL, NULL, NULL, &error)) {
+      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS)) {
+        g_warning ("Could not copy file for webextensions: %s", error->message);
+        return;
+      }
+    }
+  }
+}
