@@ -25,6 +25,8 @@
 
 #include <gtk/gtk.h>
 
+#include "ephy-adaptive-mode.h"
+#include "ephy-bookmark-states.h"
 #include "ephy-security-levels.h"
 
 G_BEGIN_DECLS
@@ -33,11 +35,6 @@ G_BEGIN_DECLS
 
 G_DECLARE_FINAL_TYPE (EphyLocationEntry, ephy_location_entry, EPHY, LOCATION_ENTRY, GtkOverlay)
 
-typedef enum {
-  EPHY_LOCATION_ENTRY_BOOKMARK_ICON_HIDDEN,
-  EPHY_LOCATION_ENTRY_BOOKMARK_ICON_EMPTY,
-  EPHY_LOCATION_ENTRY_BOOKMARK_ICON_BOOKMARKED
-} EphyLocationEntryBookmarkIconState;
 
 GtkWidget      *ephy_location_entry_new                        (void);
 
@@ -51,8 +48,8 @@ void            ephy_location_entry_undo_reset                 (EphyLocationEntr
 
 void            ephy_location_entry_focus                      (EphyLocationEntry *entry);
 
-void            ephy_location_entry_set_bookmark_icon_state    (EphyLocationEntry                  *entry,
-                                                                EphyLocationEntryBookmarkIconState  state);
+void            ephy_location_entry_set_bookmark_icon_state    (EphyLocationEntry     *entry,
+                                                                EphyBookmarkIconState  state);
 
 void            ephy_location_entry_set_lock_tooltip           (EphyLocationEntry *entry,
                                                                 const char        *tooltip);
@@ -79,5 +76,12 @@ gboolean        ephy_location_entry_get_reader_mode_state      (EphyLocationEntr
 void            ephy_location_entry_set_progress               (EphyLocationEntry *entry,
                                                                 gdouble            progress,
                                                                 gboolean           loading);
+void            ephy_location_entry_page_action_add            (EphyLocationEntry *entry,
+                                                                GtkWidget         *action);
+
+void            ephy_location_entry_page_action_clear          (EphyLocationEntry *entry);
+
+void            ephy_location_entry_set_adaptive_mode          (EphyLocationEntry *entry,
+                                                                EphyAdaptiveMode   adpative_mode);
 
 G_END_DECLS
